@@ -214,13 +214,6 @@ def dutycycle(df, speed_name, torque_name, stepx, stepy, bubblesize, xlimleft,xl
     plt.show()
 
 
-
-df=pd.read_csv('C:/Users/lx379/Desktop/9_1.csv')
-dutycycle(df,'ESPDAve(rpm)','TorquePercentage_(%)',100,10,20,0,2000,0,100,'15N KnockDerate Vehicle Dutycycle')
-
-
-
-
 # dutycycle3d plot | 20.dec.14
 def dutycycle3d(df,speed_name, torque_name, barnum, title):
     from mpl_toolkits.mplot3d import Axes3D
@@ -2021,6 +2014,8 @@ def polynominalreg(df,x_parameter,y_parameter,M,title):
 # polynominalreg(df,'para-1','para-2',5,'demo')
 
 
+# df=pd.read_csv('C:/Users/lx379/Desktop/9_2.csv')
+# dutycycle(df,'ESPDAve(rpm)','TorquePercentage_(%)',100,10,15,0,2000,0,100,'15N Vehicle Dutycycle')
 
 
 this_is_nothing = 'Below modules are not validated.---------------------👇'
